############################# Replication file ##################################

# load data
load("H:/Documents/EAN/Health networks/CBHC/CBHC_replication_data.RData")

### load library
library(statnet)
library(ggplot2)
library(tidyverse)
library(Hmisc)
library(stargazer)
library(RColorBrewer)
library(gplots)

################################## Figures ################################## 

### Figure 1 ###
hclustfunc <- function(x) hclust(x, method="ward.D2")
distfunc <- function(x) dist(x,method="euclidean")
cols <- brewer.pal(max(groups), "YlGnBu")

heatmap.2(as.matrix(mydata),dendrogram="row", Colv=FALSE, trace="none",cexRow=1,cexCol=1,margins=c(12,10), 
          col=colorRampPalette(brewer.pal(8, "Blues"))(10), lhei = c(1,3),
          hclust=hclustfunc, distfun=distfunc, RowSideColors=cols[groups])

### Figure 3 ###
degree_long %>%
  mutate(ms = fct_reorder(ms, value, sum)) %>% 
  ggplot(aes(ms, Value)) +
  geom_col(aes(fill=interaction, x=ms, y=value)) +
  #geom_point( color="#F8766D", size=3) +
  coord_flip() +
  ylab("Degree centrality (# named)") +
  xlab("") + 
  scale_fill_grey(name="Interaction type",
                  breaks=c("advice", "bestpractice", "information"),
                  c("Providing advice","Exchanging best practices","Exchanging information")) +
  theme_minimal() 
dev.off()


##################################### ERGMs ###################################### 

# Advice
advice_model = ergm(advice_nw ~ edges + gwesp(.3, fixed = TRUE) + 
                      nodematch("cluster")  + 
                      nodeifactor("cluster1") +
                      #nodeifactor("cluster2") +
                      #nodeofactor("cluster3") +
                      #nodeofactor("cluster4") +
                      #nodeofactor("cluster5") +
                      #nodeicov("prior_authorization") +
                      #nodeicov("no_prior_authorization") +
                      edgecov(patient_flows_no_prior) + 
                      edgecov(patient_flows_prior) + 
                      #edgecov(geo_mat) +
                      nodeicov("staff"))

# Best Practices
bestpractice_model = ergm(bestpractice_nw ~ edges + gwesp(.3, fixed = TRUE) + 
                            nodematch("cluster")  + 
                            nodeifactor("cluster1") +
                            #nodeicov("prior_authorization") +
                            #nodeicov("no_prior_authorization") +
                            edgecov(patient_flows_no_prior) + 
                            edgecov(patient_flows_prior) + 
                            #edgecov(geo_mat) +
                            nodeicov("staff")) 

# Information
information_model = ergm(information_nw ~ edges + gwesp(.3, fixed = TRUE) + 
                           nodematch("cluster")  + 
                           nodeifactor("cluster1") +
                           #nodeicov("prior_authorization") +
                           #nodeicov("no_prior_authorization") +
                           edgecov(patient_flows_no_prior) + 
                           edgecov(patient_flows_prior) + 
                           #edgecov(geo_mat) +
                           nodeicov("staff")) 


#### Table 2 ###

stargazer(advice_model, bestpractice_model, information_model, type="text",
          star.cutoffs = c(.1, .05, .01, .001), star.char = c("+", "*", "**", "***"),
          notes = c("+ p<0.1; * p<0.05; ** p<0.01; *** p<0.001"), 
          notes.append = F, style="default")


### Goodness of fit diagnostics ###
gof_advice <- gof(advice_model ~ idegree + esp + distance)
gof_bestpractice <- gof(bestpractice_model ~ idegree + esp + distance)
gof_information <- gof(information_model ~ idegree + esp + distance)

par(mfrow = c(2,2))
plot(gof_advice, main="Advice")

par(mfrow = c(2,2))
plot(gof_bestpractice, main ="Best practices")

par(mfrow = c(2,2))
plot(gof_information, main = "Information")
